package com.fs.hisStore.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.hisStore.domain.FsStoreOrderOfflineScrm;
import com.fs.hisStore.param.FsStoreOrderOfflineCreateParam;
import com.fs.hisStore.param.FsStoreOrderOfflineParam;
import com.fs.hisStore.vo.FsStoreOrderOfflineListVO;

/**
 * 线下订单Service接口
 *
 * @author fs
 * @date 2024-10-29
 */
public interface IFsStoreOrderOfflineScrmService
{
    /**
     * 查询线下订单
     *
     * @param orderId 线下订单ID
     * @return 线下订单
     */
    public FsStoreOrderOfflineScrm selectFsStoreOrderOfflineById(Long orderId);

    /**
     * 查询线下订单列表
     *
     * @param fsStoreOrderOffline 线下订单
     * @return 线下订单集合
     */
    public List<FsStoreOrderOfflineScrm> selectFsStoreOrderOfflineList(FsStoreOrderOfflineScrm fsStoreOrderOffline);

    /**
     * 新增线下订单
     *
     * @param fsStoreOrderOffline 线下订单
     * @return 结果
     */
    public int insertFsStoreOrderOffline(FsStoreOrderOfflineScrm fsStoreOrderOffline);

    /**
     * 修改线下订单
     *
     * @param fsStoreOrderOffline 线下订单
     * @return 结果
     */
    public int updateFsStoreOrderOffline(FsStoreOrderOfflineScrm fsStoreOrderOffline);

    /**
     * 批量删除线下订单
     *
     * @param orderIds 需要删除的线下订单ID
     * @return 结果
     */
    public int deleteFsStoreOrderOfflineByIds(Long[] orderIds);

    /**
     * 删除线下订单信息
     *
     * @param orderId 线下订单ID
     * @return 结果
     */
    public int deleteFsStoreOrderOfflineById(Long orderId);


    List<FsStoreOrderOfflineListVO> selectFsStoreOrderOfflineListVO(FsStoreOrderOfflineParam param);

    R createOrder(FsStoreOrderOfflineCreateParam param);

    FsStoreOrderOfflineListVO selectFsStoreOrderOfflineVOById(Long orderId);

    int uploadCredentials(FsStoreOrderOfflineScrm order);
}
